# eric7.EricNetwork

Package implementing some special network related objects and functions.

### Packages

data | Package defining some data used by the networking code.

### Modules

EricFtp | Module implementing an extension to the Python FTP class to support FTP proxies.
EricGoogleMail | Module implementing a dialog to send bug reports.
EricGoogleMailHelpers | Module implementing some helpers for Google mail.
EricIPv4InputWidget | Module implementing a widget to enter an IPv4 address.
EricJsonClient | Module implementing the JSON based client base class.
EricJsonServer | Module implementing the JSON based server base class.
EricJsonStreamReader | Module implementing a JSON based reader class.
EricJsonStreamWriter | Module implementing a JSON based writer class.
EricNetworkIcon | Module implementing a statusbar icon tracking the network status.
EricNetworkProxyFactory | Module implementing a network proxy factory.
EricNetworkUtilities | Package implementing some special network related objects and functions.
EricSslCertificateSelectionDialog | Module implementing a dialog to select a SSL certificate.
EricSslCertificatesDialog | Module implementing a dialog to show and edit all certificates.
EricSslCertificatesInfoDialog | Module implementing a dialog to show SSL certificate infos.
EricSslCertificatesInfoWidget | Module implementing a widget to show SSL certificate infos.
EricSslErrorHandler | Module implementing a SSL error handler.
EricSslInfoWidget | Module implementing a widget to show SSL information.
EricSslUtilities | Module implementing SSL utility functions.
EricTldExtractor | Module implementing the TLD Extractor.
EricUrlInfo | Module implementing a class replacing QUrlInfo.